%global codename fuerte
%global shortname robot_model

Name:		ros-%{codename}-robot-model
Version:	1.8.0
Release:	1%{?dist}
Summary:	Modeling robot information for ROS
# ivcon is LGPLv2+
# http://people.sc.fsu.edu/~jburkardt/cpp_src/ivcon/ivcon.html
License:	BSD and MIT and LGPLv2+
URL:		http://ros.org/wiki/robot_model
Source0:	https://code.ros.org/svn/release/download/stacks/robot_model/robot_model-%{version}/robot_model-%{version}.tar.bz2
# They depend on an obsolete version of an abandoned codebase. Whee!
Source1:	http://pr.willowgarage.com/downloads/ConvexDecomposition.zip
# common_rosdeps is obsolete as of fuerte
Patch0:		ros-robot-model-nocr.patch
BuildRequires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
BuildRequires:	ros-%{codename}-geometry-devel, ros-%{codename}-common-msgs-devel
BuildRequires:	ros-%{codename}-orocos-kinematics-dynamics, libxml2-devel
BuildRequires:	assimp-devel, libcurl-devel, pcre-devel, tinyxml-devel
BuildRequires:	cmake, python-yaml, collada-dom-devel
BuildRequires:	chrpath
Requires:	collada-dom
Provides:	ros-%{shortname} = %{version}-%{release}
Provides:	ros-image-common = %{version}-%{release}

%description
ROS robot_model contains packages for modeling various aspects of robot 
information, specified in the Xml Robot Description Format (URDF). The core
package of this stack is urdf, which parses URDF files, and constructs an 
object model (C++) of the robot.

%package devel
Summary:	Development files for ROS robot_model
Requires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
Requires:	ros-%{codename}-geometry-devel, ros-%{codename}-common-msgs-devel
Requires:	ros-%{codename}-orocos-kinematics-dynamics, libxml2-devel
Requires:	assimp-devel, libcurl-devel, pcre-devel, tinyxml-devel
Requires:	collada-dom-devel
Requires:	%{name} = %{version}-%{release}
Provides:	ros-%{shortname}-devel = %{version}-%{release}
Provides:	ros-robot-model-devel = %{version}-%{release}

%description devel
Development files for ROS robot_model.

%prep
%setup -q -c
# We have to do this so the cmake gunk can find itself. So idiotic.
mv %{shortname}-%{version} %{shortname}
%patch0 -p1 -b .nocr

# Help it find the system collada-dom headers
pushd %{shortname}/colladadom/
ln -s %{_includedir}/collada-dom/ include
popd

# Create dirs for it that it is too dumb to make itself
mkdir -p %{shortname}/ivcon/bin

# Unpack the ConvexDecomposition bits
pushd %{shortname}/convex_decomposition
mkdir build
mkdir bin
cp %{SOURCE1} build/
cd build
unzip %{SOURCE1}
mv ConvexDecomposition convex_decomposition
cd ..
patch -d build/convex_decomposition -p0 < convex_decomposition.patch

%build
cd %{shortname}
source /etc/catkin/profile.d/10.ros.all
export ROS_PACKAGE_PATH="%{_builddir}/%{name}-%{version}:$ROS_PACKAGE_PATH"
# convex_decomposition is "special"
pushd convex_decomposition
cd build/convex_decomposition
make CFLAGS="%{optflags} -IConvexDecomposition -c -ggdb"
cd ../..
popd

for i in collada_parser urdf_parser resource_retriever urdf collada_urdf ivcon kdl_parser robot_state_publisher simmechanics_to_urdf srdf urdf_interface; do
  pushd $i
  mkdir -p build
  cd build
  %cmake -DSETUPTOOLS_DEB_LAYOUT=OFF ..
  make %{?_smp_mflags}
  popd
done

%install
cd %{shortname}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/
cp -a stack.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/

# convex_decomposition
pushd convex_decomposition
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/convex_decomposition/bin
cp -a manifest.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/convex_decomposition/
mkdir -p %{buildroot}%{_bindir}/
cp -a build/convex_decomposition/convex_decomposition %{buildroot}%{_bindir}/
ln -s %{_bindir}/convex_decomposition %{buildroot}%{_datadir}/ros-stacks/%{shortname}/convex_decomposition/bin/convex_decomposition
popd

# colladadom
pushd colladadom
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/colladadom
ln -s %{_includedir}/collada-dom/ %{buildroot}%{_datadir}/ros-stacks/%{shortname}/colladadom/include
cp -a *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/colladadom/
popd

# collada_parser
pushd collada_parser
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/collada_parser
cp -a *.xml *.dox include %{buildroot}%{_datadir}/ros-stacks/%{shortname}/collada_parser
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/collada_parser/lib
cp -a lib/libcollada_parser.so %{buildroot}%{_libdir}
ln -s %{_libdir}/libcollada_parser.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/collada_parser/lib/libcollada_parser.so
popd

# collada_urdf
pushd collada_urdf
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/collada_urdf
cp -a *.xml include %{buildroot}%{_datadir}/ros-stacks/%{shortname}/collada_urdf/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/collada_urdf/bin
cp -a bin/urdf_to_collada %{buildroot}%{_bindir}/
ln -s %{_bindir}/urdf_to_collada %{buildroot}%{_datadir}/ros-stacks/%{shortname}/collada_urdf/bin/urdf_to_collada
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/collada_urdf/lib
cp -a lib/libcollada_urdf.so %{buildroot}%{_libdir}
ln -s %{_libdir}/libcollada_urdf.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/collada_urdf/lib/libcollada_urdf.so
popd

# ivcon
pushd ivcon
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/ivcon/bin
cp -a *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/ivcon/
cp -a bin/ivcon %{buildroot}%{_bindir}/
ln -s %{_bindir}/ivcon %{buildroot}%{_datadir}/ros-stacks/%{shortname}/ivcon/bin/ivcon
popd

# kdl_parser
pushd kdl_parser
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/kdl_parser
cp -a *.xml include %{buildroot}%{_datadir}/ros-stacks/%{shortname}/kdl_parser/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/kdl_parser/bin
cp -a bin/check_kdl_parser %{buildroot}%{_bindir}/
ln -s %{_bindir}/check_kdl_parser %{buildroot}%{_datadir}/ros-stacks/%{shortname}/kdl_parser/bin/check_kdl_parser
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/kdl_parser/lib
cp -a lib/libkdl_parser.so %{buildroot}%{_libdir}/
ln -s %{_libdir}/libkdl_parser.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/kdl_parser/lib/libkdl_parser.so
popd

# resource_retriever
pushd resource_retriever
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/resource_retriever
cp -a *.dox *.xml include %{buildroot}%{_datadir}/ros-stacks/%{shortname}/resource_retriever/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/resource_retriever/lib
cp -a lib/libresource_retriever.so %{buildroot}%{_libdir}/
ln -s %{_libdir}/libresource_retriever.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/resource_retriever/lib/libresource_retriever.so
mkdir -p %{buildroot}/%{python_sitelib}
cp -a src/resource_retriever %{buildroot}/%{python_sitelib}/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/resource_retriever/src
ln -s %{python_sitelib}/resource_retriever %{buildroot}%{_datadir}/ros-stacks/%{shortname}/resource_retriever/src/resource_retriever
popd

# robot_state_publisher
pushd robot_state_publisher
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/robot_state_publisher
cp -a *.dox *.xml include %{buildroot}%{_datadir}/ros-stacks/%{shortname}/robot_state_publisher/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/robot_state_publisher/bin
cp -a bin/state_publisher %{buildroot}%{_bindir}/
ln -s %{_bindir}/state_publisher %{buildroot}%{_datadir}/ros-stacks/%{shortname}/robot_state_publisher/bin/state_publisher
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/robot_state_publisher/lib
cp -a lib/librobot_state_publisher.so %{buildroot}%{_libdir}/
ln -s %{_libdir}/librobot_state_publisher.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/robot_state_publisher/lib/librobot_state_publisher.so
popd

# simmechanics_to_urdf
pushd simmechanics_to_urdf
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/simmechanics_to_urdf
cp -a *.py *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/simmechanics_to_urdf/
popd

# srdf
pushd srdf
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/srdf
cp -a include *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/srdf/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/srdf/lib
cp -a lib/libsrdf.so %{buildroot}%{_libdir}/
ln -s %{_libdir}/libsrdf.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/srdf/lib/libsrdf.so
popd

# urdf
pushd urdf
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf
cp -a include *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf/bin
cp -a bin/check_urdf %{buildroot}%{_bindir}/
ln -s %{_bindir}/check_urdf %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf/bin/check_urdf
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf/lib
cp -a lib/liburdf.so %{buildroot}%{_libdir}/
ln -s %{_libdir}/liburdf.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf/lib/liburdf.so
popd

# urdf_interface
pushd urdf_interface
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf_interface
cp -a *.dox *.xml include %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf_interface/
popd

# urdf_parser
pushd urdf_parser
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf_parser
cp -a *.dox *.xml include %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf_parser/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf_parser/bin
cp bin/mem_test %{buildroot}%{_bindir}/urdf_mem_test
ln -s %{_bindir}/urdf_mem_test %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf_parser/bin/mem_test
cp bin/check_urdf bin/urdf_to_graphiz %{buildroot}%{_bindir}/
ln -s %{_bindir}/check_urdf %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf_parser/bin/check_urdf
ln -s %{_bindir}/urdf_to_graphiz %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf_parser/bin/urdf_to_graphiz
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf_parser/lib
cp -a lib/liburdf_parser.so %{buildroot}%{_libdir}/
ln -s %{_libdir}/liburdf_parser.so %{buildroot}%{_datadir}/ros-stacks/%{shortname}/urdf_parser/lib/liburdf_parser.so
popd

chrpath -d %{buildroot}%{_bindir}/* 
chrpath -d %{buildroot}%{_libdir}/*.so

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_bindir}/check_urdf
%{_bindir}/urdf_mem_test
%{_bindir}/urdf_to_graphiz
%{_bindir}/state_publisher
%{_bindir}/check_kdl_parser
%{_bindir}/ivcon
%{_bindir}/urdf_to_collada
%{_bindir}/convex_decomposition
%{_datadir}/ros-stacks/%{shortname}/
%exclude %{_datadir}/ros-stacks/%{shortname}/colladadom/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/collada_parser/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/collada_urdf/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/kdl_parser/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/resource_retriever/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/robot_state_publisher/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/srdf/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/urdf/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/urdf_interface/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/urdf_parser/include/
%{_libdir}/libcollada_parser.so
%{_libdir}/libcollada_urdf.so
%{_libdir}/libkdl_parser.so
%{_libdir}/libresource_retriever.so
%{_libdir}/librobot_state_publisher.so
%{_libdir}/libsrdf.so
%{_libdir}/liburdf.so
%{_libdir}/liburdf_parser.so
%{python_sitelib}/resource_retriever

%files devel
%{_datadir}/ros-stacks/%{shortname}/colladadom/include/
%{_datadir}/ros-stacks/%{shortname}/collada_parser/include/
%{_datadir}/ros-stacks/%{shortname}/collada_urdf/include/
%{_datadir}/ros-stacks/%{shortname}/kdl_parser/include/
%{_datadir}/ros-stacks/%{shortname}/resource_retriever/include/
%{_datadir}/ros-stacks/%{shortname}/robot_state_publisher/include/
%{_datadir}/ros-stacks/%{shortname}/srdf/include/
%{_datadir}/ros-stacks/%{shortname}/urdf/include/
%{_datadir}/ros-stacks/%{shortname}/urdf_interface/include/
%{_datadir}/ros-stacks/%{shortname}/urdf_parser/include/

%changelog
* Fri Jun  1 2012 Tom Callaway <spot@fedoraproject.org> - 1.8.0-1
- initial package
